<?php

namespace Fastrack\Seo;

use SilverStripe\Forms\CheckboxField;
use SilverStripe\Forms\DropdownField;
use SilverStripe\Forms\FieldList;
use SilverStripe\Forms\HeaderField;
use SilverStripe\Forms\TextField;
use SilverStripe\ORM\DataExtension;
use SilverStripe\View\Requirements;
use SwiftDevLabs\CodeEditorField\Forms\CodeEditorField;

class SiteSeoExtension extends DataExtension
{

	private static $db = [
		'SiteTitleUsage' => 'Enum(array("Do not use", "As prefix", "As postfix")',
		'TitleSeparator' => 'Varchar(255)',
		'IsLive' => 'Boolean',
		'UsesHttps' => 'Boolean',
		'PrimaryDomain' => 'Varchar(255)',
		'JavaScriptHead' => 'Text',
		'JavaScriptBodyTop' => 'Text',
		'JavaScriptBodyBottom' => 'Text',
	];

	private static $translate = [
		'TitleSeparator',
	];

	public function updateCMSFields(FieldList $fields)
	{
		$fields->addFieldsToTab('Root.Main', $this->getMainTabFields());
		$fields->addFieldsToTab('Root.CustomHTML', $this->getCustomHtmlFields());
	}

	private function getCustomHtmlFields()
	{
		Requirements::set_force_js_to_bottom(true);
		$mode = 'ace/mode/html';
		return [
			HeaderField::create('JavaScriptTitle', 'On page custom HTML and JavaScript'),
			CodeEditorField::create('JavaScriptHead', 'HTML inside <head> tag')->setMode($mode),
			CodeEditorField::create('JavaScriptBodyTop', 'HTML after the <body> tag')->setMode($mode),
			CodeEditorField::create('JavaScriptBodyBottom', 'HTML before </body> tag')->setMode($mode),
		];
	}

	private function getMainTabFields()
	{
		$siteTitleUsageValues = singleton($this->owner->getClassName())->dbObject('SiteTitleUsage')->enumValues();
		return [
			TextField::create('PrimaryDomain', 'Primary domain'),
			CheckboxField::create('IsLive', 'Is live'),
			CheckboxField::create('UsesHttps', 'Uses HTTPS'),
			HeaderField::create('SeoTitle', 'SEO'),
			DropdownField::create('SiteTitleUsage', 'Meta title usage of [site title]', $siteTitleUsageValues),
			TextField::create('TitleSeparator', 'Title separator'),
		];
	}
}
